==> Cosmos7.645.tar.gz: Cosmos7.645/cosmos/bert-bl1.f <==
************************************************************************
*                                                                      *
      block data bertbl1
*                                                                      *
*       Geometrical cross section (b)                                  *
*       Bertini model data                                             *
*       last modified by K.Niita on 08/02/2000                         *
*                                                                      *
************************************************************************

*-----------------------------------------------------------------------

      implicit real*8 (a-h,o-z)

      common /geosig/ geosig(250)

*-----------------------------------------------------------------------

      data geosig/
     &  4.1854407D-01,  4.7798009D-01,  5.2368086D-01,
     &  5.6227827D-01,  5.9633539D-01,  6.2716689D-01,
     &  6.5555495D-01,  6.8200908D-01,  7.0688386D-01,
     &  7.3043723D-01,  7.5286413D-01,  7.7431586D-01,
     &  7.9491303D-01,  8.1475300D-01,  8.3391628D-01,
     &  8.5247018D-01,  8.7047127D-01,  8.8796816D-01,
     &  9.0500285D-01,  9.2161153D-01,  9.3782625D-01,
     &  9.5367487D-01,  9.6918251D-01,  9.8437127D-01,
     &  9.9926126D-01,  1.0138704D+00,  1.0282148D+00,
     &  1.0423092D+00,  1.0561670D+00,  1.0698006D+00,
     &  1.0832210D+00,  1.0964387D+00,  1.1094633D+00,
     &  1.1223033D+00,  1.1349672D+00,  1.1474624D+00,
     &  1.1597961D+00,  1.1719747D+00,  1.1840042D+00,
     &  1.1958907D+00,  1.2076394D+00,  1.2192555D+00,
     &  1.2307434D+00,  1.2421079D+00,  1.2533531D+00,
     &  1.2644830D+00,  1.2755015D+00,  1.2864120D+00,
     &  1.2972179D+00,  1.3079224D+00,  1.3185288D+00,
     &  1.3290396D+00,  1.3394579D+00,  1.3497859D+00,
     &  1.3600267D+00,  1.3701823D+00,  1.3802551D+00,
     &  1.3902471D+00,  1.4001606D+00,  1.4099977D+00,
     &  1.4197600D+00,  1.4294494D+00,  1.4390680D+00,
     &  1.4486171D+00,  1.4580985D+00,  1.4675139D+00,
     &  1.4768643D+00,  1.4861517D+00,  1.4953775D+00,
     &  1.5045425D+00,  1.5136484D+00,  1.5226966D+00,
     &  1.5316881D+00,  1.5406239D+00,  1.5495052D+00,
     &  1.5583334D+00,  1.5671092D+00,  1.5758336D+00,
     &  1.5845081D+00,  1.5931330D+00,  1.6017097D+00,
     &  1.6102386D+00,  1.6187210D+00,  1.6271578D+00,
     &  1.6355494D+00,  1.6438968D+00,  1.6522010D+00,
     &  1.6604625D+00,  1.6686820D+00,  1.6768601D+00,
     &  1.6849978D+00,  1.6930957D+00,  1.7011543D+00,
     &  1.7091743D+00,  1.7171563D+00,  1.7251010D+00,
     &  1.7330088D+00,  1.7408803D+00,  1.7487163D+00,
     &  1.7565172D+00,  1.7642833D+00,  1.7720152D+00,
     &  1.7797137D+00,  1.7873791D+00,  1.7950118D+00,
     &  1.8026122D+00,  1.8101808D+00,  1.8177184D+00,
     &  1.8252250D+00,  1.8327012D+00,  1.8401474D+00,
     &  1.8475639D+00,  1.8549514D+00,  1.8623099D+00,
     &  1.8696401D+00,  1.8769420D+00,  1.8842162D+00,
     &  1.8914631D+00,  1.8986830D+00,  1.9058761D+00,
     &  1.9130432D+00,  1.9201838D+00,  1.9272990D+00,
     &  1.9343886D+00,  1.9414532D+00,  1.9484932D+00,
     &  1.9555085D+00,  1.9624996D+00,  1.9694667D+00,
     &  1.9764102D+00,  1.9833305D+00,  1.9902276D+00,
     &  1.9971015D+00,  2.0039531D+00,  2.0107825D+00,
     &  2.0175896D+00,  2.0243748D+00,  2.0311383D+00,
     &  2.0378807D+00,  2.0446016D+00,  2.0513019D+00,
     &  2.0579814D+00,  2.0646400D+00,  2.0712787D+00,
     &  2.0778974D+00,  2.0844960D+00,  2.0910751D+00,
     &  2.0976345D+00,  2.1041749D+00,  2.1106962D+00,
     &  2.1171985D+00,  2.1236819D+00,  2.1301469D+00,
     &  2.1365937D+00,  2.1430223D+00,  2.1494327D+00,
     &  2.1558256D+00,  2.1622007D+00,  2.1685584D+00,
     &  2.1748987D+00,  2.1812217D+00,  2.1875281D+00,
     &  2.1938171D+00,  2.2000898D+00,  2.2063457D+00,
     &  2.2125853D+00,  2.2188089D+00,  2.2250163D+00,
     &  2.2312076D+00,  2.2373832D+00,  2.2435427D+00,
     &  2.2496872D+00,  2.2558160D+00,  2.2619296D+00,
     &  2.2680279D+00,  2.2741112D+00,  2.2801798D+00,
     &  2.2862336D+00,  2.2922726D+00,  2.2982972D+00,
     &  2.3043075D+00,  2.3103035D+00,  2.3162850D+00,
     &  2.3222526D+00,  2.3282062D+00,  2.3341462D+00,
     &  2.3400724D+00,  2.3459849D+00,  2.3518839D+00,
     &  2.3577696D+00,  2.3636418D+00,  2.3695008D+00,
     &  2.3753470D+00,  2.3811799D+00,  2.3870000D+00,
     &  2.3928074D+00,  2.3986021D+00,  2.4043843D+00,
     &  2.4101536D+00,  2.4159108D+00,  2.4216557D+00,
     &  2.4273882D+00,  2.4331087D+00,  2.4388170D+00,
     &  2.4445133D+00,  2.4501979D+00,  2.4558708D+00,
     &  2.4615315D+00,  2.4671810D+00,  2.4728187D+00,
     &  2.4784451D+00,  2.4840603D+00,  2.4896637D+00,
     &  2.4952563D+00,  2.5008376D+00,  2.5064078D+00,
     &  2.5119669D+00,  2.5175153D+00,  2.5230528D+00,
     &  2.5285795D+00,  2.5340955D+00,  2.5396009D+00,
     &  2.5450954D+00,  2.5505799D+00,  2.5560538D+00,
     &  2.5615172D+00,  2.5669704D+00,  2.5724137D+00,
     &  2.5778464D+00,  2.5832694D+00,  2.5886820D+00,
     &  2.5940848D+00,  2.5994775D+00,  2.6048590D+00,
     &  2.6102361D+00,  2.6155988D+00,  2.6209522D+00,
     &  2.6262960D+00,  2.6316304D+00,  2.6394273D+00,
     &  2.6469205D+00,  2.6544194D+00,  2.6613570D+00,
     &  2.6688813D+00,  2.6758327D+00,  2.6833774D+00,
     &  2.6909327D+00,  2.6979128D+00,  2.7054885D+00,
     &  2.7124925D+00/

*-----------------------------------------------------------------------

      end block data

==> Cosmos8.02.tar.gz: Cosmos8.02/cosmos/bert-bl1.f <==
!************************************************************************
!*                                                                      *
      block data bertbl1
!*                                                                      *
!*       Geometrical cross section (b)                                  *
!*       Bertini model data                                             *
!*       last modified by K.Niita on 08/02/2000                         *
!*                                                                      *
!************************************************************************

!*-----------------------------------------------------------------------

      implicit real*8 (a-h,o-z)

      common /geosig/ geosig(250)

!*-----------------------------------------------------------------------

      data geosig/
     &  4.1854407D-01,  4.7798009D-01,  5.2368086D-01,
     &  5.6227827D-01,  5.9633539D-01,  6.2716689D-01,
     &  6.5555495D-01,  6.8200908D-01,  7.0688386D-01,
     &  7.3043723D-01,  7.5286413D-01,  7.7431586D-01,
     &  7.9491303D-01,  8.1475300D-01,  8.3391628D-01,
     &  8.5247018D-01,  8.7047127D-01,  8.8796816D-01,
     &  9.0500285D-01,  9.2161153D-01,  9.3782625D-01,
     &  9.5367487D-01,  9.6918251D-01,  9.8437127D-01,
     &  9.9926126D-01,  1.0138704D+00,  1.0282148D+00,
     &  1.0423092D+00,  1.0561670D+00,  1.0698006D+00,
     &  1.0832210D+00,  1.0964387D+00,  1.1094633D+00,
     &  1.1223033D+00,  1.1349672D+00,  1.1474624D+00,
     &  1.1597961D+00,  1.1719747D+00,  1.1840042D+00,
     &  1.1958907D+00,  1.2076394D+00,  1.2192555D+00,
     &  1.2307434D+00,  1.2421079D+00,  1.2533531D+00,
     &  1.2644830D+00,  1.2755015D+00,  1.2864120D+00,
     &  1.2972179D+00,  1.3079224D+00,  1.3185288D+00,
     &  1.3290396D+00,  1.3394579D+00,  1.3497859D+00,
     &  1.3600267D+00,  1.3701823D+00,  1.3802551D+00,
     &  1.3902471D+00,  1.4001606D+00,  1.4099977D+00,
     &  1.4197600D+00,  1.4294494D+00,  1.4390680D+00,
     &  1.4486171D+00,  1.4580985D+00,  1.4675139D+00,
     &  1.4768643D+00,  1.4861517D+00,  1.4953775D+00,
     &  1.5045425D+00,  1.5136484D+00,  1.5226966D+00,
     &  1.5316881D+00,  1.5406239D+00,  1.5495052D+00,
     &  1.5583334D+00,  1.5671092D+00,  1.5758336D+00,
     &  1.5845081D+00,  1.5931330D+00,  1.6017097D+00,
     &  1.6102386D+00,  1.6187210D+00,  1.6271578D+00,
     &  1.6355494D+00,  1.6438968D+00,  1.6522010D+00,
     &  1.6604625D+00,  1.6686820D+00,  1.6768601D+00,
     &  1.6849978D+00,  1.6930957D+00,  1.7011543D+00,
     &  1.7091743D+00,  1.7171563D+00,  1.7251010D+00,
     &  1.7330088D+00,  1.7408803D+00,  1.7487163D+00,
     &  1.7565172D+00,  1.7642833D+00,  1.7720152D+00,
     &  1.7797137D+00,  1.7873791D+00,  1.7950118D+00,
     &  1.8026122D+00,  1.8101808D+00,  1.8177184D+00,
     &  1.8252250D+00,  1.8327012D+00,  1.8401474D+00,
     &  1.8475639D+00,  1.8549514D+00,  1.8623099D+00,
     &  1.8696401D+00,  1.8769420D+00,  1.8842162D+00,
     &  1.8914631D+00,  1.8986830D+00,  1.9058761D+00,
     &  1.9130432D+00,  1.9201838D+00,  1.9272990D+00,
     &  1.9343886D+00,  1.9414532D+00,  1.9484932D+00,
     &  1.9555085D+00,  1.9624996D+00,  1.9694667D+00,
     &  1.9764102D+00,  1.9833305D+00,  1.9902276D+00,
     &  1.9971015D+00,  2.0039531D+00,  2.0107825D+00,
     &  2.0175896D+00,  2.0243748D+00,  2.0311383D+00,
     &  2.0378807D+00,  2.0446016D+00,  2.0513019D+00,
     &  2.0579814D+00,  2.0646400D+00,  2.0712787D+00,
     &  2.0778974D+00,  2.0844960D+00,  2.0910751D+00,
     &  2.0976345D+00,  2.1041749D+00,  2.1106962D+00,
     &  2.1171985D+00,  2.1236819D+00,  2.1301469D+00,
     &  2.1365937D+00,  2.1430223D+00,  2.1494327D+00,
     &  2.1558256D+00,  2.1622007D+00,  2.1685584D+00,
     &  2.1748987D+00,  2.1812217D+00,  2.1875281D+00,
     &  2.1938171D+00,  2.2000898D+00,  2.2063457D+00,
     &  2.2125853D+00,  2.2188089D+00,  2.2250163D+00,
     &  2.2312076D+00,  2.2373832D+00,  2.2435427D+00,
     &  2.2496872D+00,  2.2558160D+00,  2.2619296D+00,
     &  2.2680279D+00,  2.2741112D+00,  2.2801798D+00,
     &  2.2862336D+00,  2.2922726D+00,  2.2982972D+00,
     &  2.3043075D+00,  2.3103035D+00,  2.3162850D+00,
     &  2.3222526D+00,  2.3282062D+00,  2.3341462D+00,
     &  2.3400724D+00,  2.3459849D+00,  2.3518839D+00,
     &  2.3577696D+00,  2.3636418D+00,  2.3695008D+00,
     &  2.3753470D+00,  2.3811799D+00,  2.3870000D+00,
     &  2.3928074D+00,  2.3986021D+00,  2.4043843D+00,
     &  2.4101536D+00,  2.4159108D+00,  2.4216557D+00,
     &  2.4273882D+00,  2.4331087D+00,  2.4388170D+00,
     &  2.4445133D+00,  2.4501979D+00,  2.4558708D+00,
     &  2.4615315D+00,  2.4671810D+00,  2.4728187D+00,
     &  2.4784451D+00,  2.4840603D+00,  2.4896637D+00,
     &  2.4952563D+00,  2.5008376D+00,  2.5064078D+00,
     &  2.5119669D+00,  2.5175153D+00,  2.5230528D+00,
     &  2.5285795D+00,  2.5340955D+00,  2.5396009D+00,
     &  2.5450954D+00,  2.5505799D+00,  2.5560538D+00,
     &  2.5615172D+00,  2.5669704D+00,  2.5724137D+00,
     &  2.5778464D+00,  2.5832694D+00,  2.5886820D+00,
     &  2.5940848D+00,  2.5994775D+00,  2.6048590D+00,
     &  2.6102361D+00,  2.6155988D+00,  2.6209522D+00,
     &  2.6262960D+00,  2.6316304D+00,  2.6394273D+00,
     &  2.6469205D+00,  2.6544194D+00,  2.6613570D+00,
     &  2.6688813D+00,  2.6758327D+00,  2.6833774D+00,
     &  2.6909327D+00,  2.6979128D+00,  2.7054885D+00,
     &  2.7124925D+00/

!*-----------------------------------------------------------------------

      end block data
